<?php
/**
 * Partner API Library
 * 
 * @copyright Copyright (c) 2013-2014 Unizeto Technologies SA
 * @license license.txt
 */

require_once 'operation.php';
require_once 'certumPartnerAPI/messages/messageGetStatement.php';
require_once 'certumPartnerAPI/messages/messageGetStatementResponse.php';

/*
    <operation name="getStatement" parameterOrder="getStatement">
        <input message="tns:PartnerServicePortType_getStatement"/>
        <output message="tns:PartnerServicePortType_getStatementResponse"/>
    </operation>
*/

/**
 * This class represents the operation getStatement.
 * 
 * It is based on the PartnerAPIOperation class and derives some properties and methods from that class.
 * 
 * The returned statement is in the language set with the setLanguage() method
 * so you have to invoke this method beforehand.
 * 
 * @method PartnerAPIMessageGetStatementResponse getResponseMessage() A complete response from a service
 * 
 * @package operations
 * @since 1.3.0
 */
class PartnerAPIOperationGetStatement extends PartnerAPIOperation {

    /**
     * @var PartnerAPIMessageGetStatement
     */
    protected $_input = NULL;
    
    /**
     * @var PartnerAPIMessageGetStatementResponse
     */
    protected $_output = NULL;

    /**
     * @var string
     */
    protected $_operation = 'getStatement';
    
    /**
     * The constructor.
     * 
     * It initializes input and output data.
     */
    public function __construct() {
        $this->_input  = new PartnerAPIMessageGetStatement();
        $this->_output = new PartnerAPIMessageGetStatementResponse();
    }

    /**
     * This method sets a language (two-letter code).
     * 
     * The response will be in indicated language.
     * 
     * @param string $lang
     * @return PartnerAPIOperationGetStatement
     */
    public function setLanguage($lang) {
        $this->_input->getStatement->setLanguage($lang);
        return $this;
    }
    
    /**
     * Returns a statement.
     * 
     * @return string
     */
    public function getStatement() {
        return $this->_output->getStatementResponse->statement;
    }

}
